(this.webpackJsonpstreamlit_component_template=this.webpackJsonpstreamlit_component_template||[]).push([[0],{4:function(e,t,n){e.exports=n(5)},5:function(e,t,n){"use strict";n.r(t);var o=n(2);o.a.events.addEventListener(o.a.RENDER_EVENT,(function(e){var t=e.detail,n=document.body.lastElementChild;n&&document.body.removeChild(n);var a=document.body.appendChild(document.createElement("div"));new ResizeObserver((function(e){o.a.setFrameHeight()})).observe(a),a.innerHTML=t.args.html_content;for(var i=document.getElementsByTagName("a"),s=function(e){i[e].onclick=function(){o.a.setComponentValue(i[e].id)}},c=0;c<i.length;c++)s(c)})),o.a.setComponentReady()}},[[4,1,2]]]);
//# sourceMappingURL=main.924e8b5c.chunk.js.map