self.__precacheManifest = (self.__precacheManifest || []).concat([
  {
    "revision": "7943343ba793a0f868bacbd18937c4b9",
    "url": "./index.html"
  },
  {
    "revision": "1327b198531705364e94",
    "url": "./static/js/2.04f38cb3.chunk.js"
  },
  {
    "revision": "ea9e8a04b4530945f0b69f09f74b01e4",
    "url": "./static/js/2.04f38cb3.chunk.js.LICENSE.txt"
  },
  {
    "revision": "e1f91c9c7b485707bb4e",
    "url": "./static/js/main.924e8b5c.chunk.js"
  },
  {
    "revision": "7c26bca7e16783d14d15",
    "url": "./static/js/runtime-main.11ec9aca.js"
  }
]);